#
# spec file for package python-PeakUtils
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-PeakUtils
Version:        1.3.5
Release:        1.2
Summary:        Peak detection utilities for 1D data
License:        MIT
URL:            https://bitbucket.org/lucashnegri/peakutils
Source:         https://files.pythonhosted.org/packages/source/p/peakutils/peakutils-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-numpy
Requires:       python-scipy
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pandas}
BuildRequires:  %{python_module scipy}
# /SECTION
%python_subpackages

%description
This package provides utilities related to the detection of peaks on
1D data. Includes functions to estimate baselines, finding the
indexes of peaks in the data and performing Gaussian fitting or
centroid computation to further increase the resolution of the peak
detection.

%prep
%autosetup -p1 -n peakutils-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pyunittest -v tests/peakutils_test.py

%files %{python_files}
%doc README.rst
%license LICENSE.txt
%{python_sitelib}/peakutils
%{python_sitelib}/PeakUtils-%{version}.dist-info

%changelog
* Wed Aug 14 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.3.5:
  * Support scipy 1.14.
- Switch to pyproject macros.
* Wed Feb 28 2024 Markéta Machová <mmachova@suse.com>
- Actually run tests
* Wed May 31 2023 Dirk Müller <dmueller@suse.com>
- update to 1.3.4:
  * fix indexes() returning an empty float64 array
  * Change to linalg.pinv()
* Tue Apr 20 2021 Steve Kowalik <steven.kowalik@suse.com>
- Do not build with Python 3.6, due to no NumPy.
* Thu Jan 30 2020 Todd R <toddrme2178@gmail.com>
- Update to 1.3.3
  * Add exp to the source package
  * Fixed problem with peakplot function using pandas data frames
* Sun Jan 27 2019 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
- update to version 1.3.2:
  * Fix description type
- changes from version 1.3.1:
  * Simplify setup.py and add missing fields
* Thu Oct 11 2018 Arun Persaud <arun@gmx.de>
- specfile:
  * remove devel from noarch
  * be more specific in %%files section
- update to version 1.3.0:
  * added plateau test to perf.py
  * fixed failing test on indexes function
  * improve handling of plateaus in indexing
- changes from version 1.2.0:
  * Add an option to use an absolute threshold, fixes Issue #28
  * Year bump
  * Add doc requirements
  * Update doc location
* Wed May 16 2018 toddrme2178@gmail.com
- Update to 1.1.1
  * FitError not used
  * Changes when importing the napoleon ext
  * Added plateou detection tests and comment refactoring
- Implemented single-spec version
* Thu Jan 12 2017 mardnh@gmx.de
- initial package, version 1.0.3
